@@ -3,6 +3,7 @@
 Contains helper functions for plotting qa4sm results.
 """
 from qa4sm_reader import globals
+from qa4sm_reader.exceptions import PlotterError
 
 import numpy as np
 import pandas as pd
@@ -467,12 +468,10 @@ def _make_cbar(fig, im, cax, ref_short: str, metric: str, label=None, diff_map=F
         Whether the colorbar is for a difference plot
     """
     if label is None:
-        try:
-            label = globals._metric_name[metric] + \
-                    globals._metric_description[metric].format(
-                        globals._metric_units[ref_short])
-        except KeyError as e:
-            raise Exception('The metric \'{}\' or reference \'{}\' is not known.\n'.format(metric, ref_short) + str(e))
+        label = globals._metric_name[metric] + \
+                globals._metric_description[metric].format(
+                    globals.get_metric_units(ref_short)
+                )
 
     extend = get_extend_cbar(metric)
     if diff_map:
@@ -716,7 +715,7 @@ def bin_continuous(
         nbins=4,
         min_size=5,
         **kwargs,
-) -> dict:
+) -> Union[dict, None]:
     """
     Subset the continuous metadata types
 
@@ -780,7 +779,7 @@ def bin_classes(
         meta_key: str,
         min_size=5,
         **kwargs,
-):
+) -> Union[dict, None]:
     """
     Subset the continuous metadata types
 
@@ -826,7 +825,7 @@ def bin_discrete(
         meta_key: str,
         min_size=5,
         **kwargs,
-) -> pd.DataFrame:
+) -> Union[pd.DataFrame, None]:
     """
     Provide a formatted dataframe for discrete type metadata (e.g. station or network)
 
@@ -865,7 +864,7 @@ def bin_discrete(
         formatted.append(meta_df)
     # If too few points are available to make the plots
     if not formatted:
-        return None, None
+        return None
     else:
         formatted = pd.concat(formatted)
         # return None as no CI data is needed for this plot
@@ -1220,7 +1219,7 @@ def boxplot_metadata(
         nbins=nbins,
     )
     if to_plot is None:
-        raise ValueError(
+        raise PlotterError(
             "There are too few points per metadata to generate the boxplots. You can set 'min_size'"
             "to a lower value to allow for smaller samples."
         )
@@ -1357,7 +1356,6 @@ def mapplot(
     if add_cbar:  # colorbar
         _make_cbar(fig, im, cax, ref_short, metric, label=label, diff_map=diff_map)
     style_map(ax, plot_extent, **style_kwargs)
-    fig.canvas.draw()  # very slow. necessary bcs of a bug in cartopy: https://github.com/SciTools/cartopy/issues/1207
 
     return fig, ax
 
@@ -1531,4 +1529,4 @@ def output_dpi(
 
     dpi = dpi_min + (dpi_max-dpi_min) * dpi_fraction
 
-    return dpi
+    return float(dpi)
